package ru.crystals.pos.api.card;

import java.math.BigDecimal;
import ru.crystals.pos.spi.receipt.BonusBalance;

/**
 * Бонусный баланс карты
 *
 */
public class BonusBalanceEntity implements BonusBalance {
    
    private BigDecimal balance;
    
    private BigDecimal sumAllowedToChargeOff;
    
    private BigDecimal sumToChargeOff;

    /**
     * Конструктор
     * 
     * @param balance текущий баланс бонусов на счету
     */
    public BonusBalanceEntity(BigDecimal balance) {
        super();
        this.balance = balance;
    }

    /* (non-Javadoc)
     * @see ru.crystals.pos.api.card.BonusBalance#getBalance()
     */
    @Override
    public BigDecimal getBalance() {
        return balance;
    }
    
    /**
     * Установить текущий баланс бонусов на счету
     * 
     * @param balance баланс бонусов
     */
    public void setBalance(BigDecimal balance) {
        this.balance = balance;
    }

    /* (non-Javadoc)
     * @see ru.crystals.pos.api.card.BonusBalance#getSumAllowedToChargeOff()
     */
    @Override
    public BigDecimal getSumAllowedToChargeOff() {
        return sumAllowedToChargeOff;
    }
    
    /**
     * Установить количество бонусов, что позволено списать с этого баланса в текущем чеке
     * 
     * @param sumAllowedToChargeOff {@code null}, если расчет этого "потолка списания" не производился (неизвестно сколько можно списать)
     */
    public void setSumAllowedToChargeOff(BigDecimal sumAllowedToChargeOff) {
        this.sumAllowedToChargeOff = sumAllowedToChargeOff;
    }
    
    /* (non-Javadoc)
     * @see ru.crystals.pos.api.card.BonusBalance#getSumToChargeOff()
     */
    @Override
    public BigDecimal getSumToChargeOff() {
        return sumToChargeOff;
    }

    /**
     * Установить количество бонусов, которые можно списать в текущем чеке
     * 
     * @param sumToChargeOff количество бонусов, которые можно списать в текущем чеке
     */
    public void setSumToChargeOff(BigDecimal sumToChargeOff) {
        this.sumToChargeOff = sumToChargeOff;
    }

    @Override
    public String toString() {
        return "BonusBalanceEntity{" +
                "balance=" + balance +
                ", sumAllowedToChargeOff=" + sumAllowedToChargeOff +
                ", sumToChargeOff=" + sumToChargeOff +
                '}';
    }
}
