package ru.crystals.pos.api.ext.loyal.dto;

import java.math.BigDecimal;

/**
 * Результат начисления бонусов плагином лояльности.<br>
 * Для плагина лояльности служит способом уведомить кассу о начислении бонусов на карту в результате расчета лояльности.<br>
 * Полученная информация может отображаться на сервере в Опердне или выгружаться в ERP.
 */
public class BonusAccrualResult {
    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link BonusAccrualResult}.
     */
    public BonusAccrualResult() {
        // Nop
    }

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link BonusAccrualResult}.
     * @param transactionId идентификатор транзакции начисления бонусов.
     * @param amount величина начисленных бонусов. Должно быть ненулевым неотрицательным значением.
     */
    public BonusAccrualResult(String transactionId, BigDecimal amount) {
        this.transactionId = transactionId;
        this.amount = amount;
    }
    /**
     * Идентификатор транзакции начисления бонусов на данную карту.
     */
    private String transactionId;
    /**
     * Величина начисленных бонусов.
     */
    private BigDecimal amount;

    /**
     * Получает идентификатор транзакции, которая начислила на счет карты бонусы.
     * @return идентификатор транзакции, которая начислила на счет карты бонусы.
     */
    public String getTransactionId() {
        return transactionId;
    }

    /**
     * Устанавливает идентификатор транзакции, которая начислила на счет карты бонусы.
     * @param transactionId идентификатор транзакции, которая начислила на счет карты бонусы.
     */
    public void setTransactionId(String transactionId) {
        this.transactionId = transactionId;
    }

    /**
     * Возвращает величину начисленных на счет карты бонусов.
     * @return величина начисленных на счет карты бонусов.
     */
    public BigDecimal getAmount() {
        return amount;
    }

    /**
     * Устанавливает величину начисленных на счет карты бонусов.
     * @param amount величина начисленных на счет карты бонусов.
     */
    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }

    @Override
    public String toString() {
        return "BonusAccrualResult{" +
                "transactionId='" + transactionId + '\'' +
                ", amount=" + amount +
                '}';
    }
}
