package ru.crystals.pos.api.ext.loyal.dto;

import java.math.BigDecimal;

/**
 * Скидка на позицию
 * <p>
 * NOTE: все денежные суммы представлены в {@link BigDecimal} с двумя знаками после запятой, т.е. scale=2
 *
 * @author aperevozchikov
 */
public class Discount {

    /**
     * Номер позиции, на которую дана эта скидка
     */
    private int posNo;

    /**
     * Номер карты, применение которой спровоцировало срабатывание данной скидки
     */
    private String cardNumber;

    /**
     * Размер (сумма) скидки
     */
    private BigDecimal value;

    /**
     * Идентификатор данной скидки (код скидки)
     */
    private String discountId;

    /**
     * Удобный конструктор.
     *
     * @param posNo Номер позиции, на которую дана эта скидка
     * @param cardNumber Номер карты, применение которой спровоцировало срабатывание данной скидки
     * @param value Размер скидки
     * @param discountId Идентификатор данной скидки (код скидки)
     */
    public Discount(int posNo, String cardNumber, BigDecimal value, String discountId) {
        this.posNo = posNo;
        this.cardNumber = cardNumber;
        this.value = value;
        this.discountId = discountId;
    }

    @Override
    public String toString() {
        return String.format("discount [pos-no: %s; id: %s; value: %s; card-no: %s]", getPosNo(), getDiscountId(), getValue(), getCardNumber());
    }

    /**
     * Вернет номер позиции, на которую дана эта скидка
     *
     * @return номер позиции
     */
    public int getPosNo() {
        return posNo;
    }

    /**
     * Вернет Номер карты, применение которой спровоцировало срабатывание данной скидки
     *
     * @return номер карты
     */
    public String getCardNumber() {
        return cardNumber;
    }

    /**
     * Вернет Размер скидки
     *
     * @return размер (сумму) скидки
     */
    public BigDecimal getValue() {
        return value;
    }

    /**
     * Вернет Идентификатор данной скидки (код скидки)
     *
     * @return идентификатор
     */
    public String getDiscountId() {
        return discountId;
    }
}
