package ru.crystals.pos.api.ext.loyal.dto.auxiliaries;

import ru.crystals.pos.spi.feedback.Feedback;

/**
 * Некий фидбэк, который плагину лояльности необходимо отправить в свой процессинг (ПЦ - Процессинговый Центр) по результатам расчета/применения скидок в чеке.
 *
 * @author aperevozchikov
 */
public class LoyProviderFeedback extends Feedback {

    /**
     * Количество уже совершенных попыток отправки данной информации в процессинговый центр.
     * <p>
     * NOTE: предполагается, что данное поле будет модифицировать сам плагин лояльности и, на основании достижения количества попыток
     * какого-либо порога, просто примет решение прекратить навсегда попытки отправить этот фидбэк в ПЦ.
     * Например, этот счетчик можно не менять, если произошла ошибка связи/соединения с ПЦ, и увеличивать при возникновении ошибок обработки
     * фидбэка в самом ПЦ.
     */
    private int attemptsCount = 0;

    public LoyProviderFeedback() {
        super(null);
    }

    @Override
    public String toString() {
        return String.format("loy-feedback [payload: \"%s\"; attempts: %s]", getPayload(), getAttemptsCount());
    }

    /**
     * Вернет количество уже совершенных попыток отправки данной информации в процессинговый центр.
     *
     * @return число, что представляет меру "проблемности" (уже выясненной практическим путем) доставки данного feedback'а в процессинговый центр
     */
    public int getAttemptsCount() {
        return attemptsCount;
    }

    public void setAttemptsCount(int attemptsCount) {
        this.attemptsCount = attemptsCount;
    }
}
