package ru.crystals.pos.api.ext.loyal.dto.auxiliaries;

import java.util.HashMap;
import java.util.Map;
import ru.crystals.pos.api.ext.loyal.dto.BonusAccrualResult;
import ru.crystals.pos.api.ext.loyal.dto.Slip;

import java.util.ArrayList;
import java.util.List;

/**
 * Фидбек, возвращаемый плагином кассе при событии предфискализации
 * Может иметь слипы, которые будут распечатаны вместе с основым чеком
 * */
public class PreFiscalizationFeedback {

    /**
     * Список слипов добавленных плагином
     * */
    private List<Slip> slips;

    /**
     * Мапа транзакций начисления бонусных баллов на карту по результатам расчета лояльности.<br>
     * Ключом в мапе служит номер карты, на счет которой начислены бонусные баллы, значением - описание транзакции
     * начисления на карту бонусных баллов.
     */
    private Map<String, BonusAccrualResult> bonusAccrualResults;

    /**
     * Возвращает мапу транзакций начисления бонусных баллов на карту по результатам расчета лояльности.<br>
     * Ключом в мапе служит номер карты, на счет которой начислены бонусные баллы, значением - описание транзакции
     * начисления на карту бонусных баллов.
     * @return мапа транзакций начисления бонусных баллов или пустая мапа, если начислений не было
     */
    public Map<String, BonusAccrualResult> getBonusAccrualResults() {
        if(bonusAccrualResults == null) {
            bonusAccrualResults = new HashMap<>();
        }
        return bonusAccrualResults;
    }

    /**
     * Получить список слипов
     * @return никогда не вернет null. В крайнем случае пустой список.
     * */
    public List<Slip> getSlips() {
        if(slips == null) {
            slips = new ArrayList<>();
        }
        return slips;
    }
}
