package ru.crystals.pos.api.plugin.card;

/**
 * Сущность, описывающая отклик на запрос выполнения "бонусной" (списания, отмены списания бонусов) операции по карте.
 */
public class BonusOperationResponse {
    /**
     * статус выполнения операции
     */
    private BonusOperationStatus responseStatus;

    /**
     * [заполняется только в случае успеха: {@link #responseStatus} == {@link BonusOperationStatus#OK}]
     * Идентификатор транзакции на стороне процессинга, в рамках которой была проведена операция
     */
    private String txId;

    public BonusOperationResponse(BonusOperationStatus responseStatus, String txId) {
        this.responseStatus = responseStatus;
        this.txId = txId;
    }

    public BonusOperationResponse() {
        // default
    }

    /**
     * вернет статус выполнения операции
     *
     * @return {@code null} будет распознаваться как {@link BonusOperationStatus#OK}
     */
    public BonusOperationStatus getResponseStatus() {
        return responseStatus;
    }

    public void setResponseStatus(BonusOperationStatus responseStatus) {
        this.responseStatus = responseStatus;
    }

    /**
     * Вернет идентификатор транзакции на стороне процессинга, в рамках которой была проведена операция
     *
     * @return {@code null}, если операцию выполнить не удалось ({@link #getResponseStatus()} != {@link BonusOperationStatus#OK})
     */
    public String getTxId() {
        return txId;
    }

    public void setTxId(String txId) {
        this.txId = txId;
    }

    @Override
    public String toString() {
        return String.format("BonusOperationResponse {\n\tresponseStatus: \"%s\",\n\ttxId: \"%s\"\n}",
                responseStatus == null ? "null" : responseStatus.toString(),
                txId == null ? "null" : txId);
    }
}
