package ru.crystals.pos.api.plugin.card;

/**
 * Сущность, описывающая отклик на запрос списания бонусов с карты.
 */
public class BonusWriteOffOperationResponse extends BonusOperationResponse {

    /**
     * Текст сообщения, что надо показать кассиру
     */
    private String operatorMessage;

    public BonusWriteOffOperationResponse(BonusOperationStatus responseStatus, String txId, String operatorMessage) {
        super(responseStatus, txId);
        this.operatorMessage = operatorMessage;
    }

    public BonusWriteOffOperationResponse() {
        // default
    }

    /**
     * Вернет текст сообщения, что надо показать кассиру по результатам списания.
     * <p>
     * Например, данное сообщение может соджержать кратное локализованное описание ошибки, в понятном кассиру виде.
     * Или какой-нибудь рекламный текст (например, если это оказалось милионное успешное списание средств в процессинге).
     *
     * @return {@code null} либо пустая строка, если не надо показывать сообщений
     * NOTE: если вернет пустую строку, но {@link #getResponseStatus() результат} операции при этом будет отрицательным, то касса SET10 самомстоятельно
     * сформирует шаблонное сообщение об ошибке.
     */
    public String getOperatorMessage() {
        return operatorMessage;
    }

    public void setOperatorMessage(String operatorMessage) {
        this.operatorMessage = operatorMessage;
    }

    @Override
    public String toString() {
        // Статический анализ врушничает: условие operatorMessage == null не всегда false.
        return super.toString() + "operatorMessage = \"" + operatorMessage == null ? "null" : operatorMessage + "\"";
    }
}
