package ru.crystals.pos.api.plugin.card;

import java.util.ArrayList;
import java.util.List;
import ru.crystals.pos.api.card.CardEntity;

/**
 * Сущность, описывающая отклик на запрос информации по карте/купону.
 */
public class CardSearchResponse {

    private CardSearchResponseStatus responseStatus;

    private CardEntity card;

    private List<String> сashierMessages = new ArrayList<>();

    /**
     * Конструктор
     * 
     * @param responseStatus
     *            статус запроса карты
     * @see CardSearchResponseStatus
     */
    public CardSearchResponse(CardSearchResponseStatus responseStatus) {
        super();
        this.responseStatus = responseStatus;
    }

    /**
     * Конструктор
     * 
     * @param responseStatus
     *            статус запроса карты
     * @param card
     *            карта
     * @see CardSearchResponseStatus
     * @see CardEntity
     */
    public CardSearchResponse(CardSearchResponseStatus responseStatus, CardEntity card) {
        super();
        this.responseStatus = responseStatus;
        this.card = card;
    }

    /**
     * Получить статус отклика
     *
     * @return не {@code null}
     * @see CardSearchResponseStatus
     */
    public CardSearchResponseStatus getResponseStatus() {
        return responseStatus;
    }

    /**
     * Установить статус отклика
     * 
     * @param responseStatus статус
     * @see CardSearchResponseStatus
     */
    public void setResponseStatus(CardSearchResponseStatus responseStatus) {
        this.responseStatus = responseStatus;
    }

    /**
     * Вернет саму карту, запрос на получение информации по которой был сделан.
     *
     * @return {@code null}, если карта не найдена в справочнике карт по любой причине
     *         (т.е., если {@link #getResponseStatus() статус} отклика отличен от {@link CardSearchResponseStatus#OK})
     * @see CardEntity
     */
    public CardEntity getCard() {
        return card;
    }

    /**
     * Установить карту, запрос на получение информации по которой был сделан.
     * 
     * @param card
     *            {@code null}, если карта не найдена в справочнике карт по любой причине
     *            (т.е., если {@link #getResponseStatus() статус} отклика отличен от {@link CardSearchResponseStatus#OK})
     * @see CardEntity
     */
    public void setCard(CardEntity card) {
        this.card = card;
    }

    /**
     * Список сообщений, что необходимо показать кассиру при добавлении данной карты в чек.
     * <p>
     * Например, попросить кассира напомнить покупателю о необходимости заполнить анкету или заменить карту.
     * Или вызвать охрану потому что карта в "черном" списке (например, украдена).
     *
     * @return допускается возвращать {@code null} либо пустой список, если никаких сообщений кассиру показывать не требуется
     */
    public List<String> getCashierMessages() {
        return сashierMessages;
    }

    /**
     * Установить список сообщений, что необходимо показать кассиру при добавлении данной карты в чек.
     * 
     * @param сashierMessages сообщения
     * @see #getCashierMessages()
     */
    public void addСashierMessages(List<String> сashierMessages) {
        this.сashierMessages.addAll(сashierMessages);
    }

    /**
     * Добавить сообщение, что необходимо показать кассиру при добавлении данной карты в чек.
     * 
     * @param сashierMessage сообщение
     * @see #getCashierMessages()
     */
    public void addСashierMessage(String сashierMessage) {
        this.сashierMessages.add(сashierMessage);
    }
}
