package ru.crystals.pos.spi.feedback;

/**
 * Результат, содержащий "полезную нагрузку", которую плагину необходимо доставить до процессинга
 */
public class Feedback {

    private String payload;

    /**
     * Конструктор с обязательным параметром.
     * @param payload "полезная нагрузка": некое строковое представление (JSON, XML) той информации, что надо отправить в процессинговый центр (ПЦ).
     * <p>
     * NOTE: Данную строку формирует плагин и он же его должен потом "дешифровать": это обязанность разработчика
     * плагина следить за тем, чтобы обеспечить обратную совместимость (чтобы плагин версии X+ смог "понять" информацию, оставленную
     * для него плагином версии X и ниже).
     */
    public Feedback(String payload) {
        this.payload = payload;
    }

    /**
     * Получить значение "полезной нагрузки".
     * @return строковое представление "полезной нагрузки"
     */
    public String getPayload() {
        return payload;
    }

    /**
     * Установить значение "полезной нагрузки".
     * @param payload строковое представление "полезной нагрузки"
     */
    public void setPayload(String payload) {
        this.payload = payload;
    }

    @Override
    public String toString() {
        return String.format("Feedback {payload='%s'}", payload);
    }

}
