package ru.crystals.pos.spi.plugin;

import ru.crystals.pos.spi.feedback.Feedback;
import ru.crystals.pos.spi.receipt.Receipt;

/**
 * Итерфейс предок для плагинов получающих события о фискализации чека продажи/возврата/аннулирования.<br>
 * Не подлежит самостоятельной имплементации, только через предков, поэтому находится в пакете spi.
 */
public interface FiscalizationListener {

    /**
     * Событие о фискализации чека.
     * <p>
     * Предполагается, что получив это оповещение, плагин подготовит и отправит данные для отправки в процессинг.<br>
     * Реализация не подразумевает взаимодействие с UI кассы.
     *
     *
     * @param receipt чек, что был фискализирован
     * @param isCancelReceipt true - чек аннулирован, false - чек продажи или возврата
     * @return {@code null}, если отправка данных удалась.<br>
     * {@link Feedback} если отправка не удалась и необходимо выполнять периодические попытки отправки.
     * @see #onRepeatSend(Feedback)
     */
    default Feedback eventReceiptFiscalized(Receipt receipt, boolean isCancelReceipt) {
        return null;
    };

    /**
     * Повторная попытка отправить данные в процессинг.<p>
     * Реализация не подразумевает взаимодействие с UI кассы.<br>
     * Если исключений при выполнении метода не возникло, то повторные попытки отправки данных переданных в аргументе прекращаются.
     * @param goodsFeedback данные для отправки в процессинг, подготовленные ранее в методе {@link #eventReceiptFiscalized}
     * @throws Exception если повторная попытка отправки не удалась, и попытки необходимо повторять.<br>
     */
    default void onRepeatSend(Feedback goodsFeedback) throws Exception {};

}
