package ru.crystals.pos.spi.plugin;

import ru.crystals.pos.api.ext.loyal.dto.DailyReportResult;

/**
 * Поставщик сверки итогов.<br>
 * Реализация этого интерфейса позволяет плагину участвовать в процедуре сверки итогов.
 */
public interface ReconciliationReportMaker {
    /**
     * Запрашивает у внешней системы сверку итогов и возвращает её в виде печатного документа.
     * @return результат сверки итогов внешней системой или null, если плагин не проводит сверок.
     */
    default DailyReportResult createDailyReport() {
        // По умолчанию плагин этот метод не реализует.
        return null;
    }

    /**
     * Получает флаг, определяющий, умеет ли данная реализация плагина выполнять сверку итогов.<br>
     * Это необходимо для того, чтобы иметь возможность удостовериться не вызывая метода {@link #createDailyReport()}, что плагин не
     * выполняет сверку итогов.
     * @return true, если плагин умеет проводить сверку итогов и false в противном случае.
     */
    default boolean hasDailyReports() {
        return false;
    }
}
