package ru.crystals.pos.spi.plugin.goods;

import ru.crystals.pos.api.plugin.goods.NewLineItem;

/**
 * Интерфейс для оповещения кассы о результатах выполнения запроса на добавление товара в чек продажи.
 * Через этот слушатель плагин типа товаров оповещает о завершении создания позиции.
 */
public interface AddForSaleCallback {

    /**
     * Результат: товар может быть добавлен в чек продажи.
     *
     * @param newLineItem данные, которые необходимо сохранить в БД
     * @throws InvalidLineItemException исключение возникает, если аргумент {@code newLineItem} содержит некорректные данные.<br>
     * <b>Данные не будут сохранены в БД кассы.</b><br>
     * Локализованное сообщение можно получить методом {@link InvalidLineItemException#getLocalizedMessage()}<br>
     * <pre>Причинами возникновения исключения могут быть:
     *  - некорректно заполненные или пустые требуемые поля;
     *  - другими настройками кассы, блокирующими добавление (например превышение суммы чека).
     * </pre>
     * В данной ситуации рекомендуется отобразить сообщение об ошибке и,<br>если возможно, отменить добавление товара.
     */
    void completed(NewLineItem newLineItem) throws InvalidLineItemException;

    /**
     * Результат: товар не может быть добавлен в чек продажи.<p>
     * Причины могут быть разными:<br>
     * - покупатель отказался;<br>
     * - не доступен процессинг;<br>
     * - не действительный товар;<br>
     * - и т.д.
     * <p>
     * @throws CancelDeniedException возникает, когда у кассира нет привилегии для отмены позиции.<br>
     * Управление остается у плагина.<br>
     * Решается административно, например авторизацией пользователем имеющим данную привилегию.
     */
    void notCompleted() throws CancelDeniedException;
}
